.. _tutorial:

Tutorial
========

Welcome to the tutorial for ORBIT! The following examples will cover basic
usage of ORBIT through ``ProjectManager`` and available configurations. For
backround on the project and Offshore Balance of System modeling, please see
the :ref:`introduction <intro>`. For more advanced examples and real world
validation cases, please see the
`examples <https://github.com/WISDEM/ORBIT/tree/dev/examples>`_ section on
GitHub.

.. toctree::
   :maxdepth: 1
   :titlesonly:

   load_config
   project_manager
   design_phases
   phase_specific
   available_outputs
   start_dates
   define_vessels
   parametric_manager
